@@ -1,4 +1,4 @@
-use crate::{Pack, Packed, Schema, SchemaUnpack, Unpacked};
+use crate::schema::{Pack, Packed, Schema, SchemaUnpack, Unpacked};
 
 impl<'a, T, const N: usize> SchemaUnpack<'a> for [T; N]
 where
