@@ -15,7 +15,7 @@ use {
 /// Serialized exactly as [`Seq<u8>`].
 ///
 /// [`Seq<u8>`]: crate::Seq
-pub struct Bytes;
+pub enum Bytes {}
 
 impl<'a> SchemaUnpack<'a> for Bytes {
     type Unpacked = &'a [u8];
