@@ -22,6 +22,7 @@ mod option;
 mod primitive;
 mod schema;
 mod seq;
+mod str;
 mod tuple;
 
 use core::mem::size_of;
@@ -30,6 +31,7 @@ pub use self::{
     bytes::Bytes,
     schema::{Pack, Packed, Schema, SchemaUnpack, Unpacked},
     seq::{Seq, SeqUnpacked},
+    str::Str,
 };
 
 #[cfg(feature = "derive")]
