@@ -1,10 +1,10 @@
-use crate::{Pack, Packed, Schema, SchemaUnpack, Unpacked};
+use crate::schema::{Pack, Packed, Schema, SchemaUnpack, Unpacked};
 
 impl<'a, T> SchemaUnpack<'a> for Option<T>
 where
     T: Schema,
 {
-    type Unpacked = Option<<T as SchemaUnpack<'a>>::Unpacked>;
+    type Unpacked = Option<Unpacked<'a, T>>;
 }
 
 #[derive(Copy)]
