@@ -23,13 +23,20 @@ impl Pack<()> for () {
     }
 }
 
+impl Pack<()> for &'_ () {
+    #[inline(always)]
+    fn pack(self, _offset: usize, _output: &mut [u8]) -> ((), usize) {
+        ((), 0)
+    }
+}
+
 macro_rules! impl_for_tuple {
     ($packed_tuple:ident, [$($a:ident),+ $(,)?] [$($b:ident),+ $(,)?]) => {
         impl<'a, $($a),+> SchemaUnpack<'a> for ($($a,)+)
         where
             $($a: Schema,)+
         {
-            type Unpacked = ($(<$a as SchemaUnpack<'a>>::Unpacked,)+);
+            type Unpacked = ($(Unpacked<'a, $a>,)+);
         }
 
         #[derive(Copy)]
@@ -62,7 +69,7 @@ macro_rules! impl_for_tuple {
             }
 
             #[inline(always)]
-            fn unpack<'a>(packed: $packed_tuple<$($a::Packed,)+>, input: &'a [u8]) -> Unpacked<'a, Self> {
+            fn unpack<'a>(packed: $packed_tuple<$($a::Packed,)+>, input: &'a [u8]) -> ($(Unpacked<'a, $a>,)+) {
                 #![allow(non_snake_case)]
 
                 let $packed_tuple($($a,)+) = packed;
@@ -88,6 +95,25 @@ macro_rules! impl_for_tuple {
                 (packed, used)
             }
         }
+
+        impl<'a, $($a),+ , $($b),+> Pack<($($a,)+)> for &'a ($($b,)+)
+        where
+            $($a: Schema, &'a $b: Pack<$a>,)+
+        {
+            #[inline]
+            fn pack(self, offset: usize, output: &mut [u8]) -> ($packed_tuple<$($a::Packed,)+>, usize) {
+                #![allow(non_snake_case)]
+
+                let ($($b,)+) = self;
+                let mut used = 0;
+                let packed = $packed_tuple( $( {
+                    let (packed, size) = $b.pack(offset + used, &mut output[used..]);
+                    used += size;
+                    packed
+                },)+ );
+                (packed, used)
+            }
+        }
     };
 }
 
